SmsOtp class

Inheritance

Constructors

SmsOtp({Key? key, String title = "Verification", Color? titleColor, double? titleFontSize, FontWeight? titleFontWeight, double textMargin = 40, String text = "Enter the code sent to your number", Color? textColor, double? textFontSize, double phoneNumberMargin = 40, String phoneNumber = "+90 123 456 789", Color? phoneNumberColor, double? phoneNumberFontSize, double pinHeight = 68.0, double pinWidth = 64.0, double btnMargin = 40, required Function btnOnPressed, String btnText = "Enter", Color? btnTextColor, double? btnTextFontSize, double durationTimeMargin = 40, int durationTime = 3, required Function durationTimeOnEnd, Color? durationTimeTextColor, FontWeight? durationTimeTextFontWeight, double? durationTimeTextFontSize})
const

Properties

btnMargin double
final
btnOnPressed Function
final
btnText String
final
btnTextColor Color?
final
btnTextFontSize double?
final
durationTime int
final
durationTimeMargin double
final
durationTimeOnEnd Function
final
durationTimeTextColor Color?
final
durationTimeTextFontSize double?
final
durationTimeTextFontWeight FontWeight?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
phoneNumber String
final
phoneNumberColor Color?
final
phoneNumberFontSize double?
final
phoneNumberMargin double
final
pinHeight double
final
pinWidth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
textColor Color?
final
textFontSize double?
final
textMargin double
final
title String
final
titleColor Color?
final
titleFontSize double?
final
titleFontWeight FontWeight?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() SmsOtpState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited